mirador.ext package
===================

Submodules
----------

mirador.ext.django module
-------------------------

.. automodule:: mirador.ext.django
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mirador.ext
    :members:
    :undoc-members:
    :show-inheritance:
